/* SPDX-FileCopyrightText: 2009 Thomas McGuire <mcguire@kde.org>

   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
*/
#ifndef OBJECTTREEPARSERTEST_H
#define OBJECTTREEPARSERTEST_H

#include <QObject>

class ObjectTreeParserTester : public QObject
{
    Q_OBJECT

public Q_SLOTS:
    void initTestCase();

private Q_SLOTS:
    void test_HTMLOnlyText();
    void test_HTMLExternal();
    void test_Alternative();
};

#endif
