/*
   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: LGPL-2.0-or-later
*/

#include "conversationviewwidget.h"
using namespace MessageViewer;
ConversationViewWidget::ConversationViewWidget(QWidget *parent)
    : QWidget(parent)
{
}

ConversationViewWidget::~ConversationViewWidget()
{
}
