/*
   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: LGPL-2.0-or-later
*/

#ifndef CHECKPHISHINGURLUTILTEST_H
#define CHECKPHISHINGURLUTILTEST_H

#include <QObject>

class CheckPhishingUrlUtilTest : public QObject
{
    Q_OBJECT
public:
    explicit CheckPhishingUrlUtilTest(QObject *parent = nullptr);
    ~CheckPhishingUrlUtilTest();
private Q_SLOTS:
    void shouldConvertToSecond_data();
    void shouldConvertToSecond();

    void shouldCacheIsStillValid_data();
    void shouldCacheIsStillValid();

    void shouldGenerateBackModeDelay_data();
    void shouldGenerateBackModeDelay();
};

#endif // CHECKPHISHINGURLUTILTEST_H
