/*
  SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>

  SPDX-License-Identifier: LGPL-2.0-or-later
*/

#ifndef ATTACHMENTCOMPRESSJOBTEST_H
#define ATTACHMENTCOMPRESSJOBTEST_H

#include <QObject>

class AttachmentCompressJobTest : public QObject
{
    Q_OBJECT
private Q_SLOTS:
    void testCompress();
    void testCompressedSizeLarger();
};

#endif
